#include <stdio.h>
#include <string.h>
#include <stdlib.h>

const long MAX_KEYS = 30000; //30000
const long MAX_WORDS = 11000; //10000
const long MAX_WORD_LEN = 25 + 1; //20 + 1
const long PRIME_HASH_BOUND = 29989;
const long PRIMES[MAX_WORD_LEN] = 
{
	2,	3,	5,	7,	11,
	13,	17,	19,	23,	29,
	31,	37,	41,	43,	47,
	53,	59,	61,	67,	71,
	73,	79,	83,	89,	97,
	101
};

struct SWord
{
	char letters[MAX_WORD_LEN];
	long freq;
	long len;

	int operator==(const SWord &otherWord)const
	{
		return !strcmp(letters, otherWord.letters);
	}

	long GetHashCode(void)const
	{
		long number = 0;
		long len = strlen(letters), iLetter;
		for(iLetter = 0; iLetter < len; ++iLetter)
			number += letters[iLetter] * PRIMES[iLetter];
		return number % PRIME_HASH_BOUND;
	}
};

int IsPrime(long number)
{
	if(number < 2)return 0;
	if(number < 4)return 1;
	for(long factor = 2; factor <= (number >> 1); ++factor)
		if(!(number%factor))return 0;
	return 1;
}

template<class TValue, class TKey>
class CHash
{
	struct SNode
	{
		SNode *pNext;
		TValue *pValue;
	};

	SNode* lists[MAX_KEYS];

public:
	CHash(void)
	{
		memset(lists, 0, sizeof(lists));
	}

	~CHash(void)
	{
		long iList;
		SNode *pNode, *pDelNode;
		for(iList = 0; iList < MAX_KEYS; ++iList)
		{
			pNode = lists[iList];
			while(pNode)
			{
				pDelNode = pNode;
				pNode = pNode->pNext;
				delete pDelNode;
			}
		}
	}

	TValue* Find(const TValue *pValue)const
	{
		TKey key = pValue->GetHashCode();
		SNode *pNode = lists[key];
		while(pNode)
		{
			if((*pNode->pValue) == (*pValue))
				return pNode->pValue;
			pNode = pNode->pNext;
		}

		return 0;
	}

	void Add(TValue *pValue)
	{
		TKey key = pValue->GetHashCode();

		SNode *pNode = new SNode;
		pNode->pNext = lists[key];
		lists[key] = pNode;
		pNode->pValue = pValue;
	}
};

CHash<SWord, long> wordsHash;
SWord words[MAX_WORDS];
long cWords = 0;

SWord word = {"", 0, 0};

void AddWord(const SWord &newWord)
{
	SWord *pWord = wordsHash.Find(&newWord);
	if(! pWord)
	{
		words[cWords] = newWord;
		pWord = &words[cWords++];
		pWord->freq = 0;
		wordsHash.Add(pWord);
	}
	++pWord->freq;
}

int IsWordLetter(char c)
{
	if(c >= 'a' && c <= 'z')return 1;
	return 0;
}

void AddToWord(char c)
{
	if(IsWordLetter(c))
		word.letters[word.len++] = c;
	else
	{
		word.letters[word.len] = 0;
		if(word.len)AddWord(word);
		word.len = 0;
	}
}

SWord *pW1, *pW2;
int wordcmp(const void *p1, const void *p2)
{
	pW1 = (SWord*)p1;
	pW2 = (SWord*)p2;

	if(pW1->freq < pW2->freq)return 1;
	if(pW1->freq > pW2->freq)return -1;

	if(pW1->len < pW2->len)return 1;
	if(pW1->len > pW2->len)return -1;

	return strcmp(pW1->letters, pW2->letters);
}

int main(void)
{
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);

	char c;
	do
	{
		c = getchar();
		if(c>='A' && c<='Z')c = c + 'a'- 'A';
		AddToWord(c);
	}
	while(c != EOF);

	qsort(words, cWords, sizeof(words[0]), wordcmp);

	long iWord;
	for(iWord = 0; iWord < 10; ++iWord)
		puts(words[iWord].letters);

	fclose(stdin);
	fclose(stdout);

	return 0;
}
